@@ -7,8 +7,8 @@ $self = {
                       'Gtk2',
                       'Pango'
                     ],
-          'inc' => '-D_REENTRANT -I/usr/include/gdk-pixbuf-2.0 -I/usr/include/libpng16 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include  -Ibuild -Wall',
-          'libs' => '-lnotify -lgdk_pixbuf-2.0 -lm -lpng16 -lm -lz -lgio-2.0 -lz -lgmodule-2.0 -lgobject-2.0 -lffi -lglib-2.0 -lintl -lpcre -lintl -liconv -lpcre ',
+          'inc' => '-D_REENTRANT -I/usr/include/gdk-pixbuf-2.0 -I/usr/include/libpng16 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -Ibuild -Wall',
+          'libs' => '-lnotify -lgdk_pixbuf-2.0 -lgio-2.0 -lgobject-2.0 -lglib-2.0 -lintl',
           'typemaps' => [
                           'notify.typemap'
                         ]
